@@ -25,7 +25,9 @@ class AddOrderToMediaTable extends Migration
     public function up()
     {
         Schema::table('media', function(Blueprint $table) {
-            $table->integer('order')->unsigned();
+            $table->integer('order')
+                ->default(0)
+                ->unsigned();
         });
 
     }
