@@ -8,17 +8,20 @@
  * @package  Mtc\Core
  * @author   Craig McCreath <craig.mccreath@mtcmedia.co.uk>
  */
+
 namespace Mtc\Core;
 
 use DB;
 use Illuminate\Database\Eloquent\Model;
+use Illuminate\Database\Eloquent\Relations\BelongsTo;
 use Illuminate\Database\Eloquent\Relations\MorphTo;
 use Laravel\Scout\Searchable;
-use League\Flysystem\Exception;
+use Mtc\Core\CustomFields\CustomField;
 use Mtc\Core\CustomFields\CustomFieldValue;
 use Mtc\Core\CustomFields\CustomGroup;
-use Mtc\Core\Taxonomy;
+use Mtc\Media\Media;
 use Nicolaslopezj\Searchable\SearchableTrait;
+use Spatie\Translatable\HasTranslations;
 
 /**
  * The 'Node' is a cornerstone model that can connect to multiple different
@@ -34,6 +37,7 @@ use Nicolaslopezj\Searchable\SearchableTrait;
  */
 class Node extends Model
 {
+    use HasTranslations;
     use Searchable;
 
     const NODE_STATUS_PUBLISHED = 'published';
@@ -49,12 +53,29 @@ class Node extends Model
         'slug',
         'description',
         'status',
+        'featured',
         'visibility',
         'group_id',
         'custom_url',
         'url'
     ];
 
+    /**
+     * @var string[] columns to hide from output
+     */
+    protected $hidden = [
+        'created_at',
+        'updated_at'
+    ];
+
+    /**
+     * @var string[] list of fields that are translatable
+     */
+    public $translatable = [
+        'title',
+        'description'
+    ];
+
     /**
      * The array which is serialized by Laravel Scout to provide text based
      * searching.
@@ -112,7 +133,7 @@ class Node extends Model
     /**
      * Retrive information about a custom group associated with this Node.
      *
-     * @return \Illuminate\Database\Relations\BelongsTo
+     * @return BelongsTo
      */
     public function group()
     {
@@ -126,17 +147,31 @@ class Node extends Model
      */
     public function getGroupDataAttribute()
     {
-        $values = CustomFieldValue::ofGroup($this->group_id)
+        $values = CustomFieldValue::query()
+            ->ofGroup($this->group_id)
             ->ofNode($this->id)
-            ->with('field')
+            ->with([
+                'field',
+                'media'
+            ])
             ->get();
 
         $data = [];
         foreach ($values as $row) {
+            $value = $row->data_value;
+
+            if ($row->field->type === 'image') {
+                /** @var Media $value */
+                $value = $row->media->first();
+                optional($value)->setDefaultAttributes($row->field->multiple ? 'thumb' : 'small');
+            }
+
+
+            /** @var CustomFieldValue $row */
             if ($row->field->multiple) {
-                $data[$row->field->title][] = $row->value;
+                $data[$row->field->id][] = $value;
             } else {
-                $data[$row->field->title] = $row->value;
+                $data[$row->field->id] = $value;
             }
         }
         $data['node_id'] = $this->id;
@@ -154,41 +189,27 @@ class Node extends Model
     public function saveGroupData(array $data)
     {
         try {
-            // Make all entries uniform
+            // Run through data
             foreach ($data as $field_id => $value) {
-                // Multiple selects
-                if (is_array($value)) {
-                    // Delete entries that have been unselected
-                    CustomFieldValue::where('group_id', $this->group_id)
-                        ->where('field_id', $field_id)
-                        ->where('node_id', $this->id)
-                        ->whereNotIn('value', $value)
-                        ->delete();
+                /** @var CustomField $field */
+                $field = CustomField::query()->find($field_id);
 
-                    // Loop through all selected values to make sure they are saved
-                    foreach ($value as $select_value) {
-                        CustomFieldValue::firstOrNew([
-                            'group_id' => $this->group_id,
-                            'field_id' => $field_id,
-                            'node_id' => $this->id,
-                            'value' => $select_value
-                        ])->save();
-                    }
+                /*
+                 * Skip over any fields that are not passing field_id
+                 * or are referencing field that does not exist
+                 * e.g. node_id can be passed as part of data array
+                 */
+                if (!is_int($field_id) || !$field) {
                     continue;
-                } else {
-                    $custom_value = CustomFieldValue::firstOrNew([
-                        'group_id' => $this->group_id,
-                        'field_id' => $field_id,
-                        'node_id' => $this->id,
-                        'value' => $value
-                    ]);
-                    $custom_value->save();
                 }
+
+                $field->saveValue($this, $value);
             }
 
+
             // Sync taxonomies directly to node_taxonomy for better filter performance
             $this->taxonomies()->sync(
-                // Convert input array to a collection
+            // Convert input array to a collection
                 collect($data)
                     ->reject(function ($item, $key) {
                         // Find fields that have this ID and have list_id
@@ -205,7 +226,7 @@ class Node extends Model
                     ->flatten()
                     ->toArray()
             );
-        } catch (Exception $exception) {
+        } catch (\Exception $exception) {
             return false;
         }
 
