@@ -13,7 +13,10 @@ namespace Mtc\Core\Providers;
 
 use Illuminate\Support\Facades\View;
 use Illuminate\Support\ServiceProvider;
-use Mtc\Core\Http\ViewComposers\EntrustComposer;
+use Mtc\Core\Http\Controllers\CurrencyController;
+use Mtc\Core\Http\ViewComposers\CurrencyComposer;
+use Mtc\Core\Http\ViewComposers\RolesPermissionsComposer;
+use Mtc\Core\Http\ViewComposers\SeoComposer;
 
 /**
  * Registers view composers for any views.
@@ -31,8 +34,11 @@ class ComposerServiceProvider extends ServiceProvider
      */
     public function boot()
     {
-        View::composer('core::admin.user.form', EntrustComposer::class);
-        View::composer('core::admin.role.form', EntrustComposer::class);
+        View::composer('core::admin.user.form', RolesPermissionsComposer::class);
+        View::composer('core::admin.role.form', RolesPermissionsComposer::class);
+        // All requests go through Seo
+        View::composer('*', SeoComposer::class);
+        View::composer('theme::layouts.public', CurrencyComposer::class);
     }
 
     /**
